@@ -4,8 +4,7 @@ import (
 	"bufio"
 	"bytes"
 	"context"
-	// embed gpolist python binary.
-	_ "embed"
+	_ "embed" // embed gpolist python binary.
 	"errors"
 	"fmt"
 	"io/fs"
@@ -448,23 +447,43 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 
 			log.Debugf(ctx, "Parsing GPO %q", name)
 
-			class := "User"
+			// We need to consider the uppercase version of the name as well,
+			// which could occur in some of the default GPOs such as Default
+			// Domain Policy.
+			classes := []string{"User", "USER"}
 			if objectClass == ComputerObject {
-				class = "Machine"
+				classes = []string{"Machine", "MACHINE"}
 			}
-			f, err := os.Open(filepath.Join(ad.sysvolCacheDir, "Policies", filepath.Base(url), class, "Registry.pol"))
-			if errors.Is(err, fs.ErrExist) {
-				return err
-			} else if errors.Is(err, fs.ErrNotExist) {
+
+			var err error
+			var f *os.File
+			for _, class := range classes {
+				var e error
+				f, e = os.Open(filepath.Join(ad.sysvolCacheDir, "Policies", filepath.Base(url), class, "Registry.pol"))
+
+				// We only care about the first error which is caused by opening
+				// the capitalized version of the class, instead of the
+				// uppercase version which is less common and more of an edge case.
+				if e != nil && err == nil {
+					err = e
+				} else if e == nil {
+					err = nil
+					break
+				}
+			}
+
+			if errors.Is(err, fs.ErrNotExist) {
 				log.Debugf(ctx, "Policy %q doesn't have any policy for class %q %s", name, objectClass, err)
 				return nil
+			} else if err != nil {
+				return err
 			}
 			defer decorate.LogFuncOnErrorContext(ctx, f.Close)
 
 			// Decode and apply policies in gpo order. First win
 			pols, err := registry.DecodePolicy(f)
 			if err != nil {
-				return fmt.Errorf(i18n.G("%s :%v"), f.Name(), err)
+				return fmt.Errorf(i18n.G("%s: %v"), f.Name(), err)
 			}
 
 			// filter keys to be overridden
@@ -475,6 +494,9 @@ func (ad *AD) parseGPOs(ctx context.Context, gpos []gpo, objectClass ObjectClass
 				if !strings.HasPrefix(pol.Key, keyFilterPrefix) {
 					continue
 				}
+				if pol.Err != nil {
+					return fmt.Errorf(i18n.G("%s: %v"), f.Name(), pol.Err)
+				}
 				pol.Key = strings.TrimPrefix(pol.Key, keyFilterPrefix)
 
 				// Some keys can be overridden
@@ -527,11 +549,16 @@ func (ad *AD) GetStatus() (adServerURL string, isOffline bool) {
 	return ad.url, ad.isOffline
 }
 
-// NormalizeTargetName transform user or domain\user as user@domain.
+// NormalizeTargetName transforms and lowercases User or DOMAIN\User to user@domain.
 // If no domain is provided, we rely on having a default domain policy.
 func (ad *AD) NormalizeTargetName(ctx context.Context, target string, objectClass ObjectClass) (string, error) {
 	log.Debugf(ctx, "NormalizeTargetName for %q, type %q", target, objectClass)
 
+	// Lowercase the target name to ensure we don't pollute the Linux
+	// case-sensitive filesystem with multiple files based on the case of the
+	// target.
+	target = strings.ToLower(target)
+
 	if objectClass == ComputerObject {
 		return target, nil
 	}
